/**
 * Redis SET wrapper
 */
import { Base } from "./base";
/**
 * Class to handle Redis SET type
 *
 * @extends Wrapper
 */
export declare class Set extends Base {
    /**
     * Add element(s) to the set
     * Command: SADD
     *
     * @param {String[]|String} el Element or elements to add
     */
    add(...el: string[]): Promise<number>;
    /**
     * Get size of the set (number of elements in it)
     * Command: SCARD
     */
    size(): Promise<number>;
    /**
     * Check whether element is present in a set
     * Command: SISMEMBER
     *
     * @param {String} el Element to check for
     */
    has(el: string): Promise<boolean>;
    /**
     * Get all members of set as array
     * Command: SMEMBERS
     *
     */
    values(): Promise<string[]>;
    /**
     * Remove random element or number of elements from a set
     * Command: SPOP
     *
     * @param {Number} count Number of elements to remove
     */
    pop(count: number): Promise<string[]>;
    /**
     * Delete element(s) from a set
     * Command: SREM
     *
     * @param {String}  [...el] Element(s) to remove
     */
    delete(...el: string[]): Promise<number>;
}
